@@ -1,4 +1,4 @@
-#' @include SetInterval_SpecialSet.R ParameterSet.R
+
 #-------------------------------------------------------------
 # Silverman Kernel
 #-------------------------------------------------------------
@@ -31,7 +31,7 @@ NULL
 #-------------------------------------------------------------
 # Silverman Kernel Definition
 #-------------------------------------------------------------
-Silverman <- R6::R6Class("Silverman", inherit = Kernel, lock_objects = F)
+Silverman <- R6Class("Silverman", inherit = Kernel, lock_objects = F)
 Silverman$set("public","name","Silverman")
 Silverman$set("public","short_name","Silv")
 Silverman$set("public","description","Silverman Kernel")
@@ -52,4 +52,4 @@ Silverman$set("public","initialize",function(decorators = NULL){
   invisible(self)
 }) # CDF, QUANTILE & VAR MISSING
 
-.distr6$kernels = rbind(.distr6$kernels, data.table::data.table(ShortName = "Silv", ClassName = "Silverman", Support = "\u211D"))
+.distr6$kernels = rbind(.distr6$kernels, data.table::data.table(ShortName = "Silv", ClassName = "Silverman", Support = "\u211D", Packages = "-"))
