@@ -19,7 +19,7 @@ test_that("properties & traits",{
     expect_equal(Geometric$new()$symmetry, "asymmetric")
     expect_equal(Geometric$new()$sup, Inf)
     expect_equal(Geometric$new()$inf, 0)
-    expect_equal(Geometric$new()$dmax, Inf)
+    expect_equal(Geometric$new()$dmax, .Machine$double.xmax)
     expect_equal(Geometric$new()$dmin, 0)
 })
 
