@@ -15,7 +15,7 @@ test_that("properties & traits",{
   expect_equal(Gompertz$new()$symmetry, "asymmetric")
   expect_equal(Gompertz$new()$sup, Inf)
   expect_equal(Gompertz$new()$inf, 0)
-  expect_equal(Gompertz$new()$dmax, Inf)
+  expect_equal(Gompertz$new()$dmax, .Machine$double.xmax)
   expect_equal(Gompertz$new()$dmin, 0)
 })
 
