@@ -19,8 +19,8 @@ test_that("properties & traits",{
   expect_equal(l$symmetry, "symmetric")
   expect_equal(l$inf, -Inf)
   expect_equal(l$sup, Inf)
-  expect_equal(l$dmin, -Inf)
-  expect_equal(l$dmax, Inf)
+  expect_equal(l$dmin, -.Machine$double.xmax)
+  expect_equal(l$dmax, .Machine$double.xmax)
   expect_equal(l$valueSupport, "continuous")
   expect_equal(l$variateForm, "univariate")
 })
