@@ -27,7 +27,7 @@ test_that("properties & traits",{
   expect_equal(NegativeBinomial$new(form = "tbs")$inf, 10)
   expect_equal(NegativeBinomial$new(form = "fbs")$inf, 0)
   expect_equal(NegativeBinomial$new(form = "sbf")$inf, 0)
-  expect_equal(NegativeBinomial$new()$dmax,Inf)
+  expect_equal(NegativeBinomial$new()$dmax, .Machine$double.xmax)
   expect_equal(NegativeBinomial$new()$dmin, 0)
 })
 
