@@ -35,8 +35,8 @@ test_that("properties & traits",{
   expect_equal(Normal$new()$symmetry, "symmetric")
   expect_equal(Normal$new()$inf, -Inf)
   expect_equal(Normal$new()$sup, Inf)
-  expect_equal(Normal$new()$dmin, -Inf)
-  expect_equal(Normal$new()$dmax, Inf)
+  expect_equal(Normal$new()$dmin, -.Machine$double.xmax)
+  expect_equal(Normal$new()$dmax, .Machine$double.xmax)
   expect_equal(Normal$new()$valueSupport, "continuous")
   expect_equal(Normal$new()$variateForm, "univariate")
 })
