@@ -8,7 +8,7 @@ test_that("properties & traits",{
   expect_equal(Poisson$new()$symmetry, "asymmetric")
   expect_equal(Poisson$new()$sup, Inf)
   expect_equal(Poisson$new()$inf, 0)
-  expect_equal(Poisson$new()$dmax,Inf)
+  expect_equal(Poisson$new()$dmax, .Machine$double.xmax)
   expect_equal(Poisson$new()$dmin, 0)
 })
 
