@@ -18,8 +18,8 @@ test_that("properties & traits",{
   expect_equal(StudentTNoncentral$new()$symmetry, "symmetric")
   expect_equal(StudentTNoncentral$new()$sup, Inf)
   expect_equal(StudentTNoncentral$new()$inf, -Inf)
-  expect_equal(StudentTNoncentral$new()$dmax, Inf)
-  expect_equal(StudentTNoncentral$new()$dmin, -Inf)
+  expect_equal(StudentTNoncentral$new()$dmax, .Machine$double.xmax)
+  expect_equal(StudentTNoncentral$new()$dmin, -.Machine$double.xmax)
 })
 
 s = StudentTNoncentral$new(df = 2, location = 3)
