@@ -28,7 +28,7 @@ test_that("properties & traits",{
   expect_equal(Weibull$new()$inf, 0)
   expect_equal(Weibull$new()$sup, Inf)
   expect_equal(Weibull$new()$dmin, 0)
-  expect_equal(Weibull$new()$dmax, Inf)
+  expect_equal(Weibull$new()$dmax, .Machine$double.xmax)
   expect_equal(Weibull$new()$valueSupport, "continuous")
   expect_equal(Weibull$new()$variateForm, "univariate")
 })
